@@ -10,7 +10,7 @@ use IO::Socket;
 use IO::Socket::SSL;
 use Time::Crontab;
 
-our $VERSION = '1.02'; # VERSION
+our $VERSION = '1.03'; # VERSION
 
 sub new {
     my $class = shift;
@@ -94,28 +94,32 @@ sub _parent {
         );
     };
 
-    while ( my $line = $self->{socket}->getline ) {
-        print $line;
-        chomp($line);
+    eval {
+        while ( my $line = $self->{socket}->getline ) {
+            print $line;
+            chomp($line);
 
-        if ( not $session->{established} ) {
-            if ( not $session->{user} ) {
-                $self->say("USER $self->{nick} 0 * :$self->{connect}{name}");
-                $self->say("NICK $self->{nick}");
-                $session->{user} = 1;
-            }
-            elsif ( $line =~ /^:\S+\s433\s/ ) {
-                $self->nick( $self->{nick} . '_' );
-            }
-            elsif ( $line =~ /^:\S+\s001\s/ ) {
-                $self->join;
-                $session->{established} = 1;
-                alarm 1 if ( @{ $self->{ticks} } );
+            if ( not $session->{established} ) {
+                if ( not $session->{user} ) {
+                    $self->say("USER $self->{nick} 0 * :$self->{connect}{name}");
+                    $self->say("NICK $self->{nick}");
+                    $session->{user} = 1;
+                }
+                elsif ( $line =~ /^:\S+\s433\s/ ) {
+                    $self->nick( $self->{nick} . '_' );
+                }
+                elsif ( $line =~ /^:\S+\s001\s/ ) {
+                    $self->join;
+                    $session->{established} = 1;
+                    alarm 1 if ( @{ $self->{ticks} } );
+                }
             }
+
+            $delegate->($line);
         }
+    };
 
-        $delegate->($line);
-    }
+    kill( 'KILL', $_ ) for ( @{ $device->children } );
 }
 
 sub _on_message {
@@ -153,7 +157,7 @@ sub _on_message {
             $self->say( 'PONG ' . $self->{in}{text} );
             next;
         }
-        elsif ( $line =~ /^:(\S+)\s(NOTICE|\d+)\s(\S+)\s(.*)/ ) {
+        elsif ( $line =~ /^:(\S+)\s([A-Z]+|\d+)\s(\S+)\s(.*)/ ) {
             @{ $self->{in} }{ qw( source command forum text ) } = ( $1, $2, $3, $4 );
         }
         elsif ( $line =~ /^(ERROR)\s/ ) {
@@ -175,16 +179,14 @@ sub _on_message {
 
         if ( $self->{in}{to_me} ) {
             if ( $self->{in}{text} =~ /^\s*help\W*$/i ) {
-                $self->reply(
-                    ( ( $self->{in}{private} ) ? '' : $self->{in}{nick} . ': ' ) .
+                $self->reply_to(
                     'Ask me for help with "help topic" where the topic is one of the following: ' .
-                    join( ', ', sort keys %{ $self->{helps} } ) . '.'
+                    $self->list( ', ', 'and', sort keys %{ $self->{helps} } ) . '.'
                 );
                 next;
             }
             elsif ( $self->{in}{text} =~ /^\s*help\s+(.+?)\W*$/i ) {
-                $self->reply(
-                    ( ( $self->{in}{private} ) ? '' : $self->{in}{nick} . ': ' ) .
+                $self->reply_to(
                     ( $self->{helps}{$1} || "Couldn't find the help topic: $1." )
                 );
                 next;
@@ -223,7 +225,13 @@ sub load {
     for my $plugin (@_) {
         unless ( ref $plugin ) {
             if ( $plugin =~ /^:core$/i ) {
-                $self->load( qw( Join ) );
+                $self->load( qw(
+                    Math
+                    Convert
+                    Join
+                    Seen
+                    Karma
+                ) );
                 next;
             }
 
@@ -273,20 +281,14 @@ sub reload {
 sub hook {
     my ( $self, $when, $code, $attr ) = @_;
 
-    $attr //= {};
-    $attr->{priority} //= 0;
-
-    $self->{hooks} = [
-        sort {
-            $b->{attr} <=> $a->{attr}
-        }
+    push(
         @{ $self->{hooks} },
         {
             when => $when,
             code => $code,
-            attr => $attr,
+            attr => ( $attr // {} ),
         },
-    ];
+    );
 
     $self->subs(  %{ $attr->{subs}  } ) if ( ref $attr->{subs}  eq 'HASH' );
     $self->helps( %{ $attr->{helps} } ) if ( ref $attr->{helps} eq 'HASH' );
@@ -328,8 +330,10 @@ sub subs {
 
     for my $name ( keys %$subs ) {
         no strict 'refs';
+        no warnings 'redefine';
         *{ __PACKAGE__ . '::' . $name } = $subs->{$name};
     }
+
     return $self;
 }
 
@@ -354,6 +358,11 @@ sub reply {
     return $self;
 }
 
+sub reply_to {
+    my ( $self, $message ) = @_;
+    return $self->reply( ( ( not $self->{in}{private} ) ? "$self->{in}{nick}: " : '' ) . $message );
+}
+
 sub msg {
     my ( $self, $target, $message ) = @_;
     $self->say("PRIVMSG $target :$message");
@@ -385,50 +394,40 @@ sub nick {
 sub join {
     my $self = shift;
 
-    my @join = @{ ( $self->can('store') ) ? $self->store->get('join') || [] : [] };
-
-    unless (@_) {
-        if (@join) {
-            $self->say("JOIN $_") for (@join);
-        }
-        elsif ( $self->{connect}{join} ) {
-            for (
+    $self->say("JOIN $_") for (
+        ( not @_ and $self->{connect}{join} )
+            ? (
                 ( ref $self->{connect}{join} eq 'ARRAY' )
                     ? @{ $self->{connect}{join} }
                     : $self->{connect}{join}
-            ) {
-                push( @join, $_ );
-                $self->say("JOIN $_");
-            }
-        }
-    }
-    else {
-        for (@_) {
-            push( @join, $_ );
-            $self->say("JOIN $_");
-        }
-    }
-
-    $self->store->set( 'join' => \@join ) if ( $self->can('store') );
+            )
+            : @_
+    );
 
     return $self;
 }
 
 sub part {
     my $self = shift;
-
-    my @join = @{ ( $self->can('store') ) ? $self->store->get('join') || [] : [] };
-
-    for my $channel (@_) {
-        $self->say("PART $channel");
-        @join = grep { $_ ne $channel } @join;
-    }
-
-    $self->store->set( 'join' => \@join ) if ( $self->can('store') );
-
+    $self->say("PART $_") for (@_);
     return $self;
 }
 
+sub list {
+    my ( $self, $separator, $conjunction ) = ( shift, shift, shift );
+    my @list = @_;
+
+    if ( @list > 2 ) {
+        return CORE::join( $separator, @list[ 0 .. @list - 2 ], $conjunction . ' ' . $list[-1] );
+    }
+    elsif ( @list > 1 ) {
+        return $list[0] . ' ' . $conjunction . ' ' . $list[1];
+    }
+    else {
+        return $list[0];
+    }
+}
+
 1;
 
 __END__
@@ -443,7 +442,7 @@ Bot::IRC - Yet Another IRC Bot
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC)
@@ -692,9 +691,8 @@ when the trigger fires, and an optional additional attributes hashref.
             $bot->reply("$in->{nick}, don't use the word: $m->{word}.");
         },
         {
-            priority => 42,
-            subs     => [],
-            helps    => [],
+            subs  => [],
+            helps => [],
         },
     );
 
@@ -758,10 +756,8 @@ hook properly responded to the message and no additional work needs to be done.
 If the code block returns a false value, additional hooks will be checked as if
 this hook's trigger caused the code block to be skipped.
 
-The optional additional attributes hashref supports a handful of keys. The
-C<priority> value is used to sort the global set of hooks. The value is expected
-to be an integer value. The higher value priority hooks are sorted first.
-You can also specify C<subs> and C<helps>, which are exactly equivalent to
+The optional additional attributes hashref supports a handful of keys.
+You can specify C<subs> and C<helps>, which are exactly equivalent to
 calling C<subs()> and C<helps()>. (See below.)
 
 =head2 hooks
@@ -893,6 +889,13 @@ as you would in your IRC client.
 
     $bot->reply('/me feels something, which for a bot is rather impressive.');
 
+=head2 reply_to
+
+C<reply_to> is exactly like C<reply> except that if the forum for the reply is
+a channel instead of to a specific person, the bot will prepend the message
+by addressing the nick who was the source of the response the bot is responding
+to.
+
 =head2 msg
 
 Use C<msg()> when you don't have a forum to reply to or want to reply in a
@@ -932,6 +935,23 @@ Use C<part()> to part channels.
 If some sort of persistent storage plugin is loaded, the bot will remember the
 channels it has joined or parted and use that as it's initial join on restart.
 
+=head1 RANDOM HELPFUL METHODS
+
+The following are random additional methods that might be helpful in your
+plugins.
+
+=head2 list
+
+This method is a simple string method that takes a list and crafts it for
+readability. It expects a separator string, a final item conjunction string,
+and a list of items.
+
+    $bot->list( ', ', 'and', 'Alpha', 'Beta', 'Delta', 'Gamma' );
+    # returns "Alpha, Beta, Delta, and Gamma"
+
+    $bot->list( ', ', 'and', 'Alpha', 'Beta' );
+    # returns "Alpha and Beta"
+
 =head1 SEE ALSO
 
 You can look for additional information at:
